import json

from fastapi import APIRouter
from fastapi.responses import JSONResponse

from bsition.api.middleware.verify_token import VerifyTokenRoute
from bsition.api.models.document import Document, DocumentUpdate
from bsition.backend import elastic, mongo

router = APIRouter(route_class=VerifyTokenRoute)


@router.post("")
def create(aux: Document):
    mongo.create_document(json.loads(json.dumps(aux.__dict__)))
    return JSONResponse(content={"detail": "Document created"}, status_code=201)


@router.get("")
def get_documents(query: str = None):
    if query is not None:
        return elastic.search("test-index", query)
    return mongo.get_documents()


@router.get("/{id}")
def get_by_id(id: str):
    return mongo.get_document_by_id(id)


@router.put("/{id}")
def edit_data(aux: DocumentUpdate, id: str):
    if aux.data is not None:
        mongo.edit_data(id, aux.data)
    if aux.access is not None:
        mongo.edit_access(id, aux.access)
    if aux.name is not None:
        mongo.edit_name(id, aux.name)
    return JSONResponse(content={"detail": "Document updated."}, status_code=202)
