from fastapi import APIRouter
from fastapi.responses import JSONResponse

from bsition.api.middleware.verify_token import VerifyTokenRoute
from bsition.api.models.table import Table, Sort, Filter
from bsition.backend import postgres

router = APIRouter(route_class=VerifyTokenRoute)


@router.post("")
def create_table(aux: Table):
    postgres.create_table(aux.name)
    return JSONResponse(content={"detail": "Table created."}, status_code=201)


@router.put("/{name}")
def edit_table(aux: Table, name: str):
    if aux.column is not None and aux.type is not None:
        postgres.add_column(name, aux.column, aux.type)
    if aux.column_data is not None:
        postgres.insert_columns(name, aux.column_data)
    if aux.row_number is not None:
        postgres.edit_columns(name, aux.columns, aux.columns_data, aux.row_number)
    return JSONResponse(content={"detail": "Table updated."}, status_code=202)


@router.post("/{name}/sort")
def create_sort(name: str):
    postgres.create_sort(name)
    return JSONResponse(content={"detail": "Sort created."}, status_code=201)


@router.put("/{name}/sort")
def add_sort(aux: Sort, name: str):
    postgres.add_sort(name, aux.property, aux.order, aux.priority)
    return JSONResponse(content={"detail": "Sort updated."}, status_code=202)


@router.get("/{name}/sort")
def sort(name: str):
    return postgres.sort(name)


@router.post("/{name}/filter")
def create_filter(name: str):
    postgres.create_filter(name)
    postgres.add_filter_trigger(name)
    return JSONResponse(content={"detail": "Filter created."}, status_code=201)


@router.put("/{name}/filter")
def add_filter(aux: Filter, name: str):
    postgres.add_filter(name, aux.property, aux.value, aux.function)
    return JSONResponse(content={"detail": "Filter updated."}, status_code=202)


@router.get("/{name}/filter")
def filter(name: str):
    return postgres.filter(name)
