from fastapi import APIRouter, HTTPException
from fastapi.responses import JSONResponse

from bsition.api.middleware.verify_token import VerifyTokenRoute
from bsition.api.models.user import User
from bsition.backend import postgres

router = APIRouter()


@router.post("")
def create_user(user: User):
    if postgres.get_user_by_username_and_password(user.username, user.password) is not None:
        raise HTTPException(
            status_code=400,
            detail="User already exists.",
        )

    postgres.add_user(user.username, user.password)
    return JSONResponse(content={"detail": "User created."}, status_code=201)


router.route_class = VerifyTokenRoute


@router.get("")
def get_users():
    return postgres.get_users()


@router.get("/{id}")
def get_by_id(id: str):
    return postgres.get_user_by_id(id)


@router.put("/{id}")
def edit_user(aux: User, id: str):
    postgres.edit_user(id, aux.username, aux.password)
    return JSONResponse(content={"detail": "User updated."}, status_code=202)
